#
# spec file for package php7-gmagick
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define php_name    php7
%define pkg_name    gmagick
Name:           %{php_name}-%{pkg_name}
Version:        2.0.5RC1
Release:        bp153.1.17
Summary:        Wrapper to the GraphicsMagick library
License:        PHP-3.01
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/package/gmagick
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
Source1:        %{pkg_name}.ini
# PATCH-FIX-UPSTREAM fix-segfault-on-shutdown.patch https://bugs.php.net/bug.php?id=78465
Patch0:         fix-segfault-on-shutdown.patch
BuildRequires:  %{php_name}-devel
BuildRequires:  GraphicsMagick-devel
BuildRequires:  ghostscript-fonts-std
BuildRequires:  re2c
Conflicts:      php7-imagick
Provides:       php-%{pkg_name} = %{version}
Obsoletes:      php-%{pkg_name} < %{version}
%if %{?php_zend_api}0
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
%else
%requires_eq    %{php_name}
%endif

%description
PHP extension to create, modify and obtain meta information of images using
the GraphicsMagick API

%prep
%setup -q -n %{pkg_name}-%{version}
%patch0

%build
export CFLAGS="%{optflags} -fvisibility=hidden %(GraphicsMagick-config --cflags)"
%{_bindir}/phpize
%configure
%make_build

%check
%make_build PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/%{php_name}/conf.d
install -m644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{php_name}/conf.d/%{pkg_name}.ini

%files
%config(noreplace) %{_sysconfdir}/%{php_name}/conf.d/%{pkg_name}.ini
%license LICENSE
%doc CONTRIBUTORS.md README.md
%{_libdir}/%{php_name}/extensions/%{pkg_name}.so

%changelog
* Sat Jan  4 2020 Илья Индиго <ilya@ilya.pp.ua>
- Refresh spec-file.
* Sat Jan  4 2020 Arjen de Korte <suse+build@de-korte.org>
- Segfaults on shutdown need to be mitigated when GraphicsMagick is
  compiled with OpenMP support and PHP >= 7.4 only. For GCC < 9,
  the only option is to run in single thread mode, for GCC >= 9
  wait until OpenMP has relinquished its resources (modified
  fix-segfault-on-shutdown.patch).
* Sat Dec 28 2019 Arjen de Korte <suse+build@de-korte.org>
- Run in single thread mode by default to prevent a segfault on
  shutdown in PHP 7.4 (fix-segfault-on-shutdown.patch)
* Mon May 14 2018 jweberhofer@weberhofer.at
- Due to a packaging change in ghostscript the ghostscript-fonts-std
  has to be included explicitly to successfully run the tests. Elsewise
  the required helvetica-font is missing. Fix for bnc#1091930.
* Thu May 10 2018 ilya@ilya.pp.ua
- Disable tests, because test fail with php7 7.2.5. (bsc#1091930)
* Fri Mar 16 2018 crrodriguez@opensuse.org
- Build extension with -fvisibility=hidden, to limit
  chance of symbol collisions with other extensions or libraries
  loaded in the same process.
- This extenion conflicts with php7-imagick (boo#1085595)
* Thu Mar  8 2018 ilya@ilya.pp.ua
- Remove %%configure/make duplicates.
- Add %%licence macros.
* Thu Jan  4 2018 ilya@ilya.pp.ua
- Update to 2.0.5RC1
  * ChangeLog https://pecl.php.net/package-changelog.php?package=gmagick&release=2.0.5RC1
  * hasNextImage() and hasPreviousImage() now actually returns TRUE on success instead of Gmagick object.
* Tue Jul 11 2017 jweberhofer@weberhofer.at
- Cleaned up spec
- Updated dependencies
* Mon Jul 10 2017 ilya@ilya.pp.ua
- Initial package for version 2.0.4RC1
  * ChangeLog https://pecl.php.net/package-changelog.php?package=gmagick&release=2.0.4RC1
